#
# spec file for package yast2-firewall
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-firewall
Version:        5.0.1
Release:        1.4
Summary:        YaST2 - Firewall Configuration
Group:          System/YaST
License:        GPL-2.0-only
URL:            https://github.com/yast/yast-firewall

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  perl-XML-Writer
BuildRequires:  update-desktop-files
BuildRequires:  yast2-devtools >= 4.2.2
BuildRequires:  yast2-testsuite
# Replace PackageSystem with Package
BuildRequires:  yast2 >= 4.4.38
BuildRequires:  rubygem(%rb_default_ruby_abi:rspec)
BuildRequires:  rubygem(%rb_default_ruby_abi:yast-rake)

# Replace PackageSystem with Package
Requires:       yast2 >= 4.4.38
Requires:       yast2-ruby-bindings >= 1.0.0

# ButtonBox widget
Conflicts:      yast2-ycp-ui-bindings < 2.17.3
# CpiMitigations
Conflicts:      yast2-bootloader < 4.2.1

Provides:       yast2-config-firewall
Provides:       yast2-trans-firewall

Obsoletes:      yast2-config-firewall
Obsoletes:      yast2-trans-firewall

Supplements:    autoyast(firewall)

BuildArch:      noarch

%description
A YaST2 module to be used for configuring a firewall.

%prep
%setup -q

%check
%yast_check

%build

%install
%yast_install
%yast_metainfo

%files
%{yast_clientdir}
%{yast_libdir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_schemadir}
%{yast_icondir}
%license COPYING
%doc README.md

%changelog
* Tue Aug  6 2024 Knut Anderssen <kanderssen@suse.com>
- In case of autoinstallation keep the firewall service state in
  the Installation::SecuritySettings for not conflicting with the
  proposal (bsc#1216615)
- 5.0.1
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Tue Jan 25 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use Package module instead of PackageSystem (bsc#1194886).
- 4.4.3
* Fri Jan 21 2022 Ladislav Slezák <lslezak@suse.cz>
- Unify YaST module mocking in unit tests (related to bsc#1194784)
- 4.4.2
* Wed Jun 16 2021 José Iván López González <jlopez@suse.com>
- Use Installation::SecuritySettings (related to jsc#PM-2620).
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0 (bsc#1185510)
* Mon Mar 29 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Do not display "No widget..." error messages when opening
  a firewall zone widget (bsc#1184115).
- 4.3.11
* Fri Feb 12 2021 Ancor Gonzalez Sosa <ancor@suse.com>
- Adapted unit test to recent changes in Yast::Report (related to
  bsc#1179893)
- 4.3.10
* Fri Oct 30 2020 Knut Anderssen <kanderssen@suse.com>
- AutoYaST: When no firewall section is defined, write the service
  settings according to the proposal (bsc#1178050)
- 4.3.9
* Thu Oct 22 2020 Josef Reidinger <jreidinger@suse.com>
- Do not warn user about ssh key only authentication when
  ssh port is closed, but firewall is disabled.
  (bsc#1177953)
- 4.3.8
* Fri Oct 16 2020 Josef Reidinger <jreidinger@suse.com>
- Do not enable firewall during first stage of AutoYaST
  (bsc#1177778)
- 4.3.7
* Tue Oct 13 2020 Knut Anderssen <kanderssen@suse.com>
- Modified the warning text introduced in previous change according
  to suggestions (jsc#SLE-1567)
- 4.3.6
* Fri Oct  9 2020 Knut Anderssen <kanderssen@suse.com>
- Warn the user when the SSH port is closed or the service is
  disabled and the configured authentication is only based on SSH
  key (jsc#SLE-15675)
- 4.3.5
* Thu Aug 13 2020 Michal Filka <mfilka@suse.com>
- AutoYaST: moved the configuration into first stage (bsc#1173624)
- 4.3.4
* Tue Aug 11 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(firewall) into the spec file
  in order to install this packages if the section has been defined
  in the AY configuration file (bsc#1146494).
- 4.3.3
* Thu Jul 23 2020 Knut Anderssen <kanderssen@suse.com>
- AutoYaST: Only export modified zones when it is asked to export a
  reduced profile. (bsc#1171356)
- 4.3.2
* Thu May  7 2020 schubi@suse.de
- AutoYaST: Cleanup/improve issue handling (bsc#1171335).
- 4.3.1
* Thu May  7 2020 Josef Reidinger <jreidinger@suse.com>
- Autoyast schema: Allow optional types for string and map objects
  (bsc#1170886)
- 4.3.0
* Sat Mar 21 2020 Knut Anderssen <kanderssen@suse.com>
- Force a reset of the firewalld API instance after modifying the
  service state (bsc#1166698)
- 4.2.4
* Wed Feb 26 2020 Knut Anderssen <kanderssen@suse.com>
- AutoYaST: Added back the installation finish client for opening
  the VNC or SSH port during the first stage when used for remote
  installations (bsc#1161319)
- 4.2.3
* Tue Aug 27 2019 schubi@suse.de
- Set X-SuSE-YaST-AutoInstResource in desktop file (bsc#144894).
- 4.2.2
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.1
* Fri Apr 26 2019 jreidinger <jreidinger@suse.com>
- change proposal naming and add option to set cpu mitigations
  (bsc#1128707)
- 4.2.0
* Tue Mar 26 2019 knut.anderssen@suse.com
- Autoyast: Export zone name explicitly as it has been removed from
  the common attributes list (bsc#1130354)
- Fixed textdomain names
- 4.1.11
* Wed Jan 23 2019 knut.anderssen@suse.com
- Autoyast: do not overwrite imported configuration when editing
  and fixed check for not configured summary (fate#324662)
- 4.1.10
* Thu Jan 17 2019 knut.anderssen@suse.com
- Propose to reload the firewalld service after writing instead of
  restarting it as in other case it will unload kernel modules and
  terminate existing connections (bsc#1114673, bsc#1121277)
- 4.1.9
* Wed Jan 16 2019 jreidinger@suse.com
- Autoyast: remove unused options, move export to own class,
  add support for custom zones in autoyast profile (fate#324662)
- 4.1.8
* Fri Jan 11 2019 lslezak@suse.cz
- Fixed text domain names (bsc#1121643)
- 4.1.7
* Thu Jan 10 2019 Josef Reidinger <jreidinger@suse.com>
- Ensure that custom zones use unique name (fate#324662)
- Explicitly mention that masquerade is IPv4 only (fate#324662)
- 4.1.6
* Tue Jan  8 2019 schubi@suse.de
- Restart running firewalld service if data has been changed.
  (bsc#1114673)
- 4.1.5
* Tue Jan  8 2019 knut.anderssen@suse.com
- AutoYast schema:
  - Allowed the new 'forward_ports', 'rich_rules' and
    'source_ports' elements in zone entries (bsc#1108199)
- 4.1.4
* Thu Dec 20 2018 knut.anderssen@suse.com
- Startup dialog: Replace the old UI::ServiceStatus by the new
  CWM::ServiceWidget (bsc#1114807)
- 4.1.3
* Fri Nov 30 2018 jreidinger@suse.com
- Add ability to add/edit/remove zone (fate#324662)
- Show warning about lost selection only in ncurses and improve
  text
- add confirmation when aborting module
- 4.1.2
* Sat Nov 24 2018 Stasiek Michalski <hellcp@mailbox.org>
- Provide icon with module (boo#1109310)
- 4.1.1
* Wed Nov 21 2018 knut.anderssen@suse.com
- Drop completely old SuSEFirewall2 dialogs and modules.
  (fate#324662)
- 4.1.0
* Fri Nov  2 2018 igonzalezsosa@suse.com
- Enable and open the SSH port when only public key authentication
  is available for the root user (fate#324690).
- 4.0.34
* Wed Oct 17 2018 knut.anderssen@suse.com
- Added missing interfaces helpers requirement (fate#324662)
- 4.0.33
* Tue Oct 16 2018 knut.anderssen@suse.com
- Fixed zone_options widget test mocking (fate#324662)
- 4.0.32
* Wed Oct 10 2018 knut.anderssen@suse.com
- Small improvements to the widget for modifying the assignation
  of interfaces to zones (fate##324662):
  - Permits to split the input field entry by any combination of
    spaces or commas.
  - Initialize the zone selector with the default zone.
- 4.0.31
* Tue Oct  9 2018 knut.anderssen@suse.com
- Alert the user about unsaved changes when leaving the zone
  services configuration without applying changes (fate#324662)
- 4.0.30
* Fri Oct  5 2018 knut.anderssen@suse.com
- AutoYaST configuration: Added support to editing and resetting
  the current configuration. Improved the writing process
  (fate324662).
- 4.0.29
* Tue Oct  2 2018 knut.anderssen@suse.com
- AutoYast schema:
  - Allowed the new 'description', 'short' and 'target' elements in
    zone entries (bsc#1108199)
- 4.0.28
* Fri Sep 21 2018 igonzalezsosa@suse.com
- Add a new user interface to manage firewalld configuration
  (fate#324662).
- Supported featues:
  - Manage the firewalld service.
  - Browse interfaces and assign them to firewall zones.
  - List zones and design one of them as the default.
  - Assign services to zones.
  - Open ports.
- 4.0.27
* Mon Aug 20 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
- Changed dir of COPYING file.
* Thu Jun 28 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.0.26
* Fri Apr 27 2018 schubi@suse.de
- AutoYaST: Report whether an interface has been defined
  in more than one zone (bnc#1089855).
- 4.0.25
* Sat Apr 21 2018 knut.anderssen@suse.com
- During installation, open services defined by (Tigervnc) instead
  of the 'vnc-server' service that is shipped with (firewalld)
  (bsc#1081952).
- 4.0.24
* Tue Apr 17 2018 snwint@suse.de
- consistent wording (open/block) also for VNC ports (bsc#1089789)
- 4.0.23
* Tue Mar 27 2018 knut.anderssen@suse.com
- Translate the installation finish client title (bsc#1084136)
- 4.0.22
* Fri Mar 23 2018 knut.anderssen@suse.com
- AutoYaST SuSEFirewall2 Importer: Removed FW_LOG_ACCEPT_CRIT tag
  from the list of supported options as firewalld only log dropped
  packages and for accepted ones rich rules should be used instead
  (bsc#1086655)
- 4.0.21
* Wed Mar 21 2018 knut.anderssen@suse.com
- More fixes to the firewall AY schema (bsc#1013047)
  - Added zone 'sources' element to the AutoYaST schema file.
  - Permitted the use of 'listentry' element in list entries.
- 4.0.20
* Tue Mar 13 2018 knut.anderssen@suse.com
- Some fixes to the firewall AY schema (bsc#1013047)
  - Use "name" in zones
  - "default_zone" is a firewall attribute
- 4.0.19
* Tue Mar  6 2018 knut.anderssen@suse.com
- SuSEFirewall2 importer changes (fate#323460)
  - Use internal zone instead of trusted when the protection from
    the INT zone is enabled which fits better with the definition.
  - Removed the mapping of apache2 and apache2-ssl services to
    firewalld services since the apache package will provide the
    services definition and we will not use firewall defaults.
- 4.0.18
* Tue Feb 27 2018 jreidinger@suse.com
- Added textdomain for translation (bnc#1083015)
- 4.0.17
* Fri Feb 23 2018 schubi@suse.de
- Added textdomain for translation (bnc#1081458)
- 4.0.16
* Mon Feb 19 2018 schubi@suse.de
- Fixed "default_zone" in rnc file. (bnc#1013047)
- 4.0.15
* Thu Feb 15 2018 mfilka@suse.com
- fate#323460
  - updated summary in autoyast client to work with new firewalld
    api
- 4.0.14
* Wed Feb 14 2018 knut.anderssen@suse.com
- AutoYaST: added 'enable_firewall', 'start_firewall' and
  'FW_LOG_DROP_CRIT' to the list of supported properties for
  SuSEFirewall2 profiles and fixed a typo with 'FW_LOG_DROP_ALL'
  (fate#323460).
- 4.0.13
* Tue Feb  6 2018 gsouza@suse.com
- When firewall is called on ncurses or command line, an error
  message is presented to the user, informing him to use firewalld
  (fate#323460).
- 4.0.12
* Mon Feb  5 2018 knut.anderssen@suse.com
- AutoYaST: When a profile using the SuSEFirewall2 schema is used,
  the user is reported with an error if some property is not
  supported or with a warning in other case. (fate#323460)
- 4.0.11
* Wed Jan 31 2018 knut.anderssen@suse.com
- AutoYaST: (fate#323460)
  * Try to import again during writing in case it was not completed
  previously (ex: firewalld was not installed).
  * Enable or disable firewalld depending on the profile
- 4.0.10
* Fri Jan 19 2018 knut.anderssen@suse.com
- AutoYaST: fixed default valur for log denied packets when using
  SuSEFIrewall2 profiles (fate#323460)
- 4.0.9
* Mon Jan  8 2018 knut.anderssen@suse.com
- AutoYaST: Added support to set the default zone and export the
  configuration. (fate#323460)
- 4.0.8
* Thu Jan  4 2018 schubi@suse.de
- AutoYaST: Reading settings only if the firewalld is installed.
  (fate#323460)
- 4.0.7
* Fri Dec 22 2017 knut.anderssen@suse.com
- AutoYaST: Firewalld schema is now the default but SuSEFirewall2
  based profiles will still work although not all the properties
  are supported (#fate#323460)
- 4.0.6
* Tue Nov 21 2017 knut.anderssen@suse.com
- Proposal: When the Firewall is disabled, open/close port links
  are not shown in the proposal and are disabled in the specific
  proposal dialog (bsc#1068354).
- 4.0.5
* Wed Nov 15 2017 knut.anderssen@suse.com
- Do not touch firewalld services if it is not enabled in the
  proposal (bsc#1067915)
- Fixed a SuSEFirewallCmdLine firewalld api call.
- 4.0.4
* Thu Nov  9 2017 knut.anderssen@suse.com
- ProposalSettings: fixed an attribute name error when trying to
  block vnc port (bsc#1067320)
- 4.0.3
* Thu Nov  9 2017 knut.anderssen@suse.com
- ProposalSettings: fixed method name when vnc is enable by Linuxrc
  (bsc#1067320)
- 4.0.2
* Wed Nov  8 2017 knut.anderssen@suse.com
- Added missing require (bsc#1067180)
- 4.0.1
* Thu Oct 26 2017 knut.anderssen@suse.com
- Remove support for SuSEFirewall2 in firewall client supporting
  only firewalld (fate#323460)
- 4.0.0
* Wed Jun 14 2017 mfilka@suse.com
- bnc#1044045
  - do not raise an internal error when pushing Add button when
    "Service to Allow" list is empty
- 3.2.0
* Fri Apr  7 2017 gsouza@suse.com
- Inform the user if start/stop/restart fails bsc#962713
- 3.1.7
* Tue Jun  7 2016 igonzalezsosa@suse.com
- Stop generating autodocs (fate#320356)
- 3.1.6
* Tue May 24 2016 mchandras@suse.de
- Add support for firewalld (fate#318356)
  * Bump yast2 dependency to 3.1.191 which is the first version to
    support the firewalld backend.
- 3.1.5
* Fri Nov 13 2015 igonzalezsosa@suse.com
- fix validation of AutoYaST profiles (bnc#954412)
- 3.1.4
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
- 3.1.3
* Mon Nov 10 2014 jreidinger@suse.com
- fix breakage of progress in autoinstallation (bnc#845826)
- 3.1.2
* Wed Nov 27 2013 fehr@suse.de
- make autoyast automatically install SuSEfirewall2 when
  yast2-firewall is installed (bnc#845294)
* Thu Nov  7 2013 mfilka@suse.com
- bnc#843646
  - fixed second stage proposal to reflect changes done during
    first stage
- 3.1.1
* Wed Sep 18 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Wed Aug 21 2013 mfilka@suse.com
- moved firewall enabling / disabling from second stage to first stage
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Wed Jul 24 2013 locilka@suse.com
- Added better checking and more understandable UI to dialog for
  adding new masquerade rule (bnc#829706)
- 2.24.2
* Fri Jun 28 2013 mfilka@suse.com
- added Start / Stop commands into CLI
- 2.24.1
* Mon May  6 2013 locilka@suse.cz
- Using fixed checking for correct network definition to correctly
  support IPv6 (bnc#800592)
- Using ValidNetwork from IP module
- 2.24.0
* Mon Apr 15 2013 locilka@suse.cz
- Fixed checking for running firewall service (bnc#812606)
- 2.21.4
* Tue Nov 13 2012 tgoettlicher@suse.de
- confirmed license GPL v2
- 2.21.3
* Thu Mar 29 2012 jsuchome@suse.cz
- merged proofread texts
* Fri Nov  4 2011 locilka@suse.cz
- Added function keys for buttons (bnc#595564)
- 2.21.2
* Thu Oct 13 2011 locilka@suse.cz
- Fixed a typo in text marked for translation (bnc#722459).
- 2.21.1
* Fri Aug 26 2011 locilka@suse.cz
- Fixed Custom Rules dialog to handle additional flags (bnc#712670)
- 2.21.0
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Fri Apr  2 2010 locilka@suse.cz
- Added missing help for accepting-broadcast-reply (BNC #583046).
- Fixed HTML in help text (BNC #595204).
- 2.19.1
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (bnc#540627)
* Thu Nov 26 2009 kmachalkova@suse.cz
- Adapted to new Netmask API - prefix and netmask are now checked
  by two separate functions
- 2.19.0
* Fri Nov 20 2009 locilka@suse.cz
- Added description to the list of allowed services (FATE #306804).
* Fri Oct 23 2009 kmachalkova@suse.cz
- Enable SSH service if user opts for opening SSH port in fw
  (bnc#537980)
- 2.18.1
* Tue Jan 20 2009 locilka@suse.cz
- Updated help text according to suggestions (bnc #461406).
- 2.18.0
* Tue Jan 13 2009 locilka@suse.cz
- Dropping the IPsec support as it doesn't have service defined by
  package yet (bnc #478487).
* Mon Jan 12 2009 locilka@suse.cz
- A better sorting for allowed services and services to allow
  (bnc #461790).
- 2.17.7
* Tue Dec  2 2008 locilka@suse.cz
- Escaping HTML in Firewall summary (bnc #450895).
- 2.17.6
* Tue Dec  2 2008 ug@suse.de
- rnc file fixed
* Mon Oct 13 2008 locilka@suse.cz
- Fixed helps broken by proofreading (bnc #430521).
- 2.17.5
* Wed Sep 17 2008 locilka@suse.cz
- Fixed button labels, helps, confirmation when deleting a selected
  entry and enabling/disabling buttons considering the data listed
  in tables - all according to YaST Style Guide (bnc #421049).
- 2.17.4
* Wed Sep 10 2008 locilka@suse.cz
- Handling pop-up window close button (`cancel) (bnc #419101).
- 2.17.3
* Thu Aug 28 2008 locilka@suse.cz
- Pup-up dialogs adapted to new ButtonBox widget (FATE #303446).
- TextEntry -> InputField.
- Adapted RPM dependencies.
- 2.17.2
* Wed Jul 16 2008 locilka@suse.cz
- No more built-in YaST Firewall services...
* Tue Jul 15 2008 locilka@suse.cz
- SuSEFirewallUI and SuSEFirewallCMDLine YCP modules marked as
  internal.
- Added SuSEFirewallCMDLine documentation.
- Using [Cancel] instead of [Abort].
- 2.17.1
* Tue Jul  8 2008 locilka@suse.cz
- Explicitely enabling functionality that offers to install
  firewall packages if missing (bnc #388773).
- Adjusted firewall proposal to new API (fallback ports to open).
- 2.17.0
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Tue Apr 22 2008 ug@suse.de
- rnc file fixed
* Mon Apr 14 2008 locilka@suse.cz
- Unified Button Labels: OK instead of Accept (fate #120373).
- Fixed help (bnc #376702).
- 2.16.2
* Wed Apr  9 2008 locilka@suse.cz
- Implemented Firewall support for SMB browsing (fate #300970)
- Fixed custom-rules - adding port range (bnc #376650).
- Added Custom Rules to summary dialog (fate #303304).
- 2.16.1
* Thu Apr  3 2008 ug@suse.de
- rnc file fixed
* Tue Apr  1 2008 jsrain@suse.cz
- merged texts from proofread
* Fri Mar 28 2008 ug@suse.de
- rnc file fixed
- 2.16.0
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Mon Jan 21 2008 locilka@suse.cz
- UI adjusted to be possible to proceed with more services defined
  by package with the same name / translation.
- Requires yast2 >= 2.16.22
* Tue Dec  4 2007 locilka@suse.cz
- Merged proofread texts.
* Mon Sep 17 2007 ug@suse.de
- firewall.rnc file fixed for autoyast XML file
  validation (#211014)
- 2.15.8
* Mon Jul 30 2007 locilka@suse.cz
- 2.15.7
* Fri May 25 2007 jsrain@suse.cz
- removed outdated translations from .desktop-files (#271209)
* Wed May 16 2007 locilka@suse.cz
- Opening "service:sshd" (defined by package) instead "ssh" in the
  firewall proposal and "service:xorg-x11-Xvnc" instead of "vnc"
  (#274761)
- Disabling "ssh" by one-click-feature in the firewall proposal
  disables both "service:sshd" and "ssh" port if added manually.
- 2.15.6
* Wed May  9 2007 locilka@suse.cz
- Fixed typo (#270965).
* Wed Apr  4 2007 locilka@suse.cz
- A brand new and better revolutionary solution has been worked out
  for a firewall service starting/stopping and enabling/disabling
  in order to maximize user understanding and minimize errors
  (#259304).
- 2.15.5
* Mon Apr  2 2007 locilka@suse.cz
- Show firewall summary details on request (#230042).
- 2.15.4
* Fri Mar  2 2007 locilka@suse.cz
- Adding forgotten handling of `cancel in the Summary dialog
  (bugzilla #249777).
- 2.15.3
* Wed Feb 28 2007 locilka@suse.cz
- Check and install SuSEfirewall2 package when reading the
  configuration. Supported in yast2-2.15.15 and later (#245506).
- Disabling possibility to configure firewall in Installation in
  Network proposal when SuSEfirewall2 package is not installed.
* Tue Feb 27 2007 locilka@suse.cz
- Added support for Firewall Custom Rules (FATE #120042,
  FATE #100068). Supported settings are: Source Network, Source
  Port, Protocol, and Destination Port.
- Added new testsuite.
- 2.15.2
* Thu Feb 22 2007 locilka@suse.cz
- Fixed and unified icons in dialogs.
- 2.15.1
* Mon Dec  4 2006 locilka@suse.cz
- A little help/description for firewall module in installation
  proposal (using result of FATE #301151).
- 2.15.0
* Thu Oct 26 2006 locilka@suse.cz
- Added and fixed firewall.rnc for checking AutoYaST profile
  (#215248).
- 2.14.1
* Mon Oct  9 2006 locilka@suse.cz
- Merged SLES10 SP1 branch to openSUSE 10.2.
- 2.14.0
* Mon Oct  2 2006 locilka@suse.cz
- Merged proofread texts
- 2.13.13
* Mon Oct  2 2006 locilka@suse.cz
- Added missing firewall icon to all dialogs
- Removed warning pop-up message that firewall will be
  started/stopped when it gets enabled/disabled.
- 2.13.12
* Fri Aug 11 2006 locilka@suse.cz
- Fixed BuildRequires loop: removing yast2-installation (#198412).
- Added missing SuSEFirewallUI module.
- 2.13.11
* Tue Jul 18 2006 locilka@suse.cz
- Summary informs whether the firewall service will be running or
  stopped after the configuration gets written.
- 2.13.10
* Mon Jul 17 2006 locilka@suse.cz
- Adding help for Additional Services dialog.
- Checking port ranges for rightness.
- Checking additional services for a common mistake: separating
  entries by a comma instead of a space.
- Most of problems were mentioned in bugzilla bug #190871.
- Fixed appropriate dialog buttons for AbortDialog. Yes/No instead
  of Continue/Cancel (#187078).
- Unified starting and stopping vs. enabling and disabling the
  firewall service. Enabled firewall (start at boot) is started
  immediately after the SuSEFirewall::Write() operation
  and vice versa for disabled firewall (start manually).
- Modified .spec and Make files for building the package.
- 2.13.9
* Wed Jul 12 2006 locilka@suse.cz
- Speeding commandline up. Moving commandline definition into the
  separate YCP module SuSEFirewallCMDLine.
* Mon May 22 2006 locilka@suse.cz
- Fixing visibility of widgets in Broadcast Configuration (#175920)
- 2.13.8
* Thu Mar 23 2006 locilka@suse.cz
- Added checking for root permissions into the module startup
  process (#158483)
- 2.13.7
* Mon Mar  6 2006 locilka@suse.cz
- Adjusted BuildRequires for the package
- 2.13.6
* Mon Feb 13 2006 locilka@suse.cz
- NetworkManager has changed behavior again. Currently it reports
  its network interfaces so the NetworkManager support from 2.13.3
  is removed (#149075).
- 2.13.5
* Fri Jan 27 2006 locilka@suse.cz
- merged proofed texts
* Fri Jan  6 2006 locilka@suse.cz
- Adjusting for SLES10
- 2.13.4
* Wed Jan  4 2006 locilka@suse.cz
- Adding Network Manager support
- 2.13.3
* Mon Dec 19 2005 jsuchome@suse.cz
- merged proofed texts
- 2.13.2
* Tue Nov 29 2005 locilka@suse.cz
- Adding support for handling feature #5998: Port ranges
- 2.13.1
* Fri Sep 23 2005 locilka@suse.cz
- Adding support for VNC and SSH installations.
  VNC/SSH can be enabled/disabled by a single click
  (enhancement #113211).
- Adding more help for Advanced configuration of Allowed Services.
  Also with examples (enhancement #104635).
- 2.13.0
* Mon Sep  5 2005 locilka@suse.cz
- Fixing bug #112899
  [Advanced...] button had been truncated in some languages because
  of fixed length of the button. Changing UI to stretch when
  needed.
- 2.12.5
* Tue Aug 16 2005 locilka@suse.cz
- Fixing bug #104635
  From now, YaST doesn't complain when the additional allowed port
  is a numeric range of ports such as "550:570".
- 2.12.4
* Wed Aug 10 2005 locilka@suse.cz
- Fixing Progress in MakeProposal function (installation)
  Patch created by mvidner
- Fixing bug #103196,
  Enabling or Disabling [Change] button when needed
  Activating modification popups when double-clicked on any
  firewall network interface
- 2.12.3
* Thu Jul 28 2005 locilka@suse.cz
- Updated desktop file
- 2.12.2
* Thu Jun 30 2005 locilka@suse.cz
- Rwalter's Style Guide update (mostly texts)
- 2.12.1
* Thu May 19 2005 locilka@suse.cz
- Changed texts and labels to be YaST2 Guidelines-Compatible
- Added popup confirmation for deleting forward rule in Masquerade
* Mon May  9 2005 locilka@suse.cz
- Moving "Requires: SuSEfirewall2" to yast2 package
* Tue Apr 19 2005 locilka@suse.cz
- Applied new functional interface of ProductFeatures
- 2.12.0
* Fri Mar  4 2005 locilka@suse.cz
- fixed bug #67335
  Fixed unnecessary warning aborting the unchanged configuration
- 2.11.11
* Wed Mar  2 2005 locilka@suse.cz
- merged proofed texts
- 2.11.10
* Wed Mar  2 2005 locilka@suse.cz
- fixed bug #66119
  Profile Exported for AutoYaST had been lowercased.
  Profile Imported from AutoYaST had been uppercased.
* Mon Feb 21 2005 locilka@suse.cz
- added shortcuts for UI widgets
- 2.11.9
* Fri Feb  4 2005 locilka@suse.cz
- added missing comments for translators
- fixed bug installation proposal, tuning the configuration started
  the command line interface unstead of UI
- added descriptive label for no-zone-selected instead of blank ""
- removed colorful Glyphs from the summary
- added disabled Back button into the TreeWidget
- added proofed texts
- 2.11.8
* Mon Jan 31 2005 locilka@suse.cz
- added feature for better checking of the configuration, user is
  informed if any network interface is not assigned to any firewall
  zone and all network traffic would be blocked there
  (bugzilla #50333)
- 2.11.7
* Tue Jan 25 2005 locilka@suse.cz
- replaced SuSEfirewall2_final with SuSEfirewall2_setup for
  checking whether SuSEfirewall2 is running (bugzilla #50157)
- 2.11.6
* Mon Jan 17 2005 locilka@suse.cz
- Added comments for translators (CommandLine)
- Added CommandLine and UI handling in RedirectToMasquerade
  functionality to follow iptables/SuSEfirewall2 syntax
- Fixed redrawing of allowed services after AdditionalServices
  added
- Fixed StartNow(), StopNow() and SaveAndRestart() functionality to
  change the final service status after Write() operations
- 2.11.5
* Tue Jan 11 2005 locilka@suse.cz
- Added CommandLine support
* Mon Jan  3 2005 locilka@suse.cz
- Adjusted start/stop dialog for new CWM functionality (own
  functions for starting and stopping)
- More informative Summarization
- Support for new SuSEfirewall2's broadcast implementation
- Added help texts
- 2.11.4
* Tue Dec 21 2004 locilka@suse.cz
- New implementation of yast2-firewall UI (in progress)
- 2.11.3
* Wed Oct 27 2004 mvidner@suse.cz
- Adjusted for changes in Mode.
- 2.11.2
* Tue Oct 19 2004 locilka@suse.cz
- Fixed debug and error messages in log
* Sat Oct  2 2004 nashif@suse.de
- #46262: Firewall is always enabled
- Firewall settings not written during autoinstall
* Fri Sep 24 2004 locilka@suse.cz
- fixed bug #46043
  firewall enabled in network proposal was not disabled when user
  went back again to the network proposal and disabled it
- 2.10.12
* Mon Sep 20 2004 locilka@suse.cz
- fixed bug #45440
  although special ipppX ISDN devices were proposed as external
  devices, they weren't offered in combobox in the firewall
  editation as a single item
- 2.10.11
* Tue Sep 14 2004 locilka@suse.cz
- default values enable_firewall and open_ssh were moved into the
  control file #45240
- fixed texts to be matching the actual state of the naming of
  network interfaces #45209
* Mon Sep 13 2004 locilka@suse.cz
- fixed SuSEfirewall2 defaults to be the same as in the SFW2
  package (FW_PROTECT_FROM_INTERNAL=no FW_AUTOPROTECT_SERVICES=no).
- added ISDN::NetDeviceList() into the firewall proposal to catch
  just configured devices.
- fixed testsuites
- 2.10.10
* Fri Sep 10 2004 locilka@suse.cz
- fixed bug #44966, forgot text in CWMFirewall marked for
  translation.
* Tue Sep  7 2004 locilka@suse.cz
- fixed bug #44759 because of chaned defaults, firewall wasn't
  written in normal mode configuration
- 2.10.9
* Mon Sep  6 2004 locilka@suse.cz
- added SetModified() function to autoyast
- 2.10.8
* Mon Sep  6 2004 locilka@suse.cz
- fixed #44650 Function ActivateConfiguration now tests if you
  really want to activate (start) the configuration (not only if
  you call this function).
- 2.10.7
* Fri Sep  3 2004 locilka@suse.cz
- fixed #44656 Firewall in install proposal is disabled by default
  if there are any dial-up interfaces, they are proposed as
  external interfaces, other interfaces as internal interfaces and
  the firewall is proposed to be enabled.
* Thu Sep  2 2004 locilka@suse.cz
- fixed #44566 Wrong handling with newly added interfaces into the
  user-changed firewall proposal in the installation
- fixed #44463 Firewall can be disabled in autoyast, added dialog
  taken from the installation proposal
- fixed #44568 Firewall didn't inform about UDP and RPC services
  in the autoyast summary
- fixed #44569 Firewall in autoyast was getting interfaces from
  the running system instead of the autoyast settings
* Mon Aug 30 2004 locilka@suse.cz
- 2.10.6
* Mon Aug 30 2004 locilka@suse.cz
- added NFS-Server, NFS-Client, NIS-Server support
- added functions for searching FW_SERVICES_XXX_RPC for serv. supp.
* Mon Aug 30 2004 jsrain@suse.cz
- added CWMFirewallInterfaces::Modified () function (#44106)
- allowed CWMFirewallInterfaces to be used if Mode::config (#43904)
* Fri Aug 27 2004 locilka@suse.cz
- added allowing broadcast messages into ipp-client service
- modified testsiutes to support new broadcast option
- merged proofreaded UI messages
- fixed Bugzilla bug #40287, helptext for Traceroute improved
* Fri Aug 27 2004 visnov@suse.cz
- fix HaveService() for any device (join separated by spaces)
* Thu Aug 26 2004 locilka@suse.cz
- changed RunServiceSupport() to support all groups of interfaces
- created testsuites for all global functions
* Tue Aug 24 2004 locilka@suse.cz
- removed "SSH open by default" from the Instalation Proposal
* Mon Aug 23 2004 locilka@suse.cz
- added functionality for adding/removing devices into/from
  user-changed configuration in network proposal
- 2.10.5
* Fri Aug 20 2004 locilka@suse.cz
- fixed Bugzilla bug #43975
  FW wasn't started in install proposal when user didn't change it
- 2.10.4
* Mon Aug 16 2004 locilka@suse.cz
- added functions SetModified() and GetModified()
- added call SetModified() in all Set*() functions
- changed selecting/deselecting additional TCP/UDP services
- 2.10.3
* Tue Aug 10 2004 locilka@suse.cz
- merged proofread messages
- added support for NTP
* Fri Aug  6 2004 jsrain@suse.cz
- disable firewall enabling checkbox after all interfaces were
  deselected in interface selection popup
* Thu Aug  5 2004 locilka@suse.cz
- added support for ipp, LDAP and LDAPS
- 2.10.2
* Wed Aug  4 2004 locilka@suse.cz
- added new functionality for enabling/disabling services defined
  as list of ports and special functions
- added global handling for other YaST modules
* Fri Jul 30 2004 jsrain@suse.cz
- added popup (CWM widget) for selecting interfaces to open in
  firewall
- added the CWM widget for openning/closing the firewall
* Wed Jul 21 2004 locilka@suse.cz
- added firewall proposal (for network proposal)
- 2.10.1
* Tue Jun 15 2004 msvec@suse.cz
- 2.10.0
* Tue May  4 2004 mvidner@suse.cz
- merged proofread messages
- 2.9.12
* Fri Apr  2 2004 msvec@suse.cz
- fixed network configurations listing
- changed license to GPL
- 2.9.11
* Wed Mar 31 2004 msvec@suse.cz
- fixed [Back] button behavior in step 2 (#37700)
- 2.9.10
* Wed Mar 10 2004 sh@suse.de
- V 2.9.9
- Migration to new wizard
* Tue Mar  9 2004 lnussel@suse.de
- cast to string only if it's indeed a string to fix feature dialog
- 2.9.8
* Mon Mar  8 2004 msvec@suse.cz
- set title icon
- 2.9.7
* Fri Mar  5 2004 msvec@suse.cz
- more strict type casts
- 2.9.6
* Wed Mar  3 2004 visnov@suse.cz
- fixed type info
* Tue Mar  2 2004 lnussel@suse.de
- add option to allow IPsec traffic
- 2.9.5
* Fri Feb 20 2004 lnussel@suse.de
- fix warnings about useless global
- move masquerading setting to top so users find it easier
- state that the expert service config configures TCP services
- 2.9.4
* Sat Feb  7 2004 msvec@suse.cz
- fixed testsuite output
- 2.9.3
* Fri Feb  6 2004 msvec@suse.cz
- drop y2cc config file
- 2.9.2
* Tue Feb  3 2004 visnov@suse.cz
- use Sequencer module instead of WizardSequencer
* Mon Jan 26 2004 msvec@suse.cz
- updated for the new interpreter
- 2.9.1
* Tue Dec  2 2003 msvec@suse.cz
- extended help text (#33394)
- 2.9.0
* Sun Sep 14 2003 adrian@suse.de
- let it work in kcontrol again
- 2.8.13
* Sat Sep 13 2003 nashif@suse.de
- #30291: return list of needed packages for autoinstall
* Fri Aug 29 2003 visnov@suse.de
- fix #29659 (syntax errors)
- 2.8.11
* Mon Aug 25 2003 visnov@suse.de
- clarify a help text
- 2.8.10
* Wed Aug 20 2003 jsuchome@suse.de
- removed redundant "initialization dialog" (#28779)
- 2.8.9
* Mon Aug 11 2003 visnov@suse.de
- merged in proofread texts
- 2.8.8
* Tue Aug  5 2003 visnov@suse.de
- read and write also DMZ/INT/EXT services and all interfaces
- 2.8.7
* Mon Aug  4 2003 nashif@suse.de
- Fixed sequence for autoyast
- 2.8.6
* Mon Aug  4 2003 visnov@suse.de
- added API for enabling and disabling services
- added desktop file
- 2.8.5
* Wed Jul 30 2003 msvec@suse.cz
- further sources and texts cleanup
- 2.8.4
* Tue Jul 22 2003 msvec@suse.cz
- sources cleanup and fixes
- 2.8.3
* Tue Jul 15 2003 msvec@suse.de
- fix the help text (#27857)
- updated testsuite
- 2.8.2
* Thu Jun 26 2003 msvec@suse.cz
- updated to the current yast2 interface
- added minimal testsuite
- 2.8.1
* Fri Mar  7 2003 nashif@suse.de
- dont clone unconfigured firewall ( #24792 )
- 2.7.7
* Tue Mar  4 2003 mvidner@suse.de
- Texts from final proofreading.
- 2.7.6
* Wed Feb 26 2003 nashif@suse.de
- fixed bug when writing config in autoinst mode (#24221)
- Use Runlevel to set runlevels
- Improved Write function and removed duplicate code
- 2.7.5
* Thu Feb 20 2003 nashif@suse.de
- bug #23887: Finish installation after configuration is written
- Using common text: Finish instead of Quit.
- 2.7.4
* Mon Feb 17 2003 nashif@suse.de
- Read configuration if firewall is activated
- 2.7.2
* Wed Feb  5 2003 lnussel@suse.de
- apply proof read texts
* Mon Feb  3 2003 nashif@suse.de
- use SuSEFirewall module
- added autoinstallation support
- removed obsolete _write client
* Thu Jan 30 2003 lnussel@suse.de
- apply proof read texts
- 2.7.0
* Mon Sep  2 2002 mvidner@suse.cz
- Fixed firewall deactivation (broken by stricter insserv) (#18735).
- 2.6.6
* Tue Aug 27 2002 jsuchome@suse.cz
- provide/obsolete old translation packages
* Mon Jul 22 2002 lnussel@suse.de
- more proof read texts
- import Wizard instead of including it
* Fri Jul 12 2002 arvin@suse.de
- use proper namespace for Args and CallFunction (#16776)
* Thu Jul 11 2002 lnussel@suse.de
- re-insert proof read texts
* Mon Jul  8 2002 arvin@suse.de
- moved non binary files to /usr/share/YaST2
* Tue Jul  2 2002 arvin@suse.de
- removed personal-firewall.scr (use the one from yast2-network)
* Mon Jul  1 2002 msvec@suse.cz
- renamed to yast2-firewall
- 2.6.0
* Fri Mar  8 2002 lnussel@suse.de
- fix error dialog to display stdout and stderr, add TERM=raw to the
  environment of the initscript to avoid escape sequences (#14695)
* Thu Feb 28 2002 mike@suse.de
- undo "insert proofreaded texts" because the translation are
  based on not proofreaded texts
* Thu Feb 21 2002 lnussel@suse.de
- marked two more strings for translation
* Thu Feb 21 2002 lnussel@suse.de
- dialogs for stopping the firewall
* Tue Feb 19 2002 lnussel@suse.de
- use /etc/sysconfig/personal-firewall
- minor fixes
* Mon Feb 18 2002 mike@suse.de
- first working version
* Tue Feb 12 2002 tom@suse.de
- Renamed menuentry_firewall.y2cc ---> menuentry_firewall2.y2cc (conflict)
* Fri Feb  8 2002 tom@suse.de
- Now checked into STABLE
* Fri Feb  8 2002 mike@suse.de
- initial version
